@@ -20,7 +20,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QList>
+#include <QDate>
 #include <QRegExp>
 #include <QSharedData>
 #include <QUuid>
@@ -30,8 +30,6 @@
 
 #include "addresseehelper.h"
 #include "field.h"
-#include "sortmode.h"
-
 #include "addressee.h"
 
 using namespace KContacts;
@@ -94,7 +92,7 @@ public:
         mLogoExtraList = other.mLogoExtraList;
         mUrlExtraList = other.mUrlExtraList;
         mMembers = other.mMembers;
-        mRelationShips = other.mRelationShips;
+        mRelationships = other.mRelationships;
         mSources = other.mSources;
         mEmpty = other.mEmpty;
         mImpps = other.mImpps;
@@ -147,7 +145,7 @@ public:
     ResourceLocatorUrl::List mUrlExtraList;
     QVector<QUrl> mSources;
     QStringList mMembers;
-    Related::List mRelationShips;
+    Related::List mRelationships;
     FieldGroup::List mFieldGroupList;
     Title::List mTitleExtraList;
     Role::List mRoleExtraList;
@@ -157,12 +155,8 @@ public:
     bool mEmpty    : 1;
     bool mChanged  : 1;
     bool mBirthdayWithTime;
-
-    static KContacts::SortMode *mSortMode;
 };
 
-KContacts::SortMode *Addressee::Private::mSortMode = nullptr;
-
 Addressee::Addressee()
     : d(new Private)
 {
@@ -368,8 +362,8 @@ bool Addressee::operator==(const Addressee &addressee) const
         qCDebug(KCONTACTS_LOG) << "Extra url differs";
         return false;
     }
-    if (!listEquals(d->mRelationShips, addressee.d->mRelationShips)) {
-        qCDebug(KCONTACTS_LOG) << "RelationShips differs";
+    if (!listEquals(d->mRelationships, addressee.d->mRelationships)) {
+        qCDebug(KCONTACTS_LOG) << "Relationships differs";
         return false;
     }
     if (!listEquals(d->mSources, addressee.d->mSources)) {
@@ -1433,7 +1427,7 @@ void Addressee::setNameFromString(const QString &s)
             setFamilyName(parts[rightOffset - 1] + spaceStr + parts[rightOffset]);
             rightOffset--;
         } else {
-            if (helper->tradeAsFamilyName()) {
+            if (helper->treatAsFamilyName()) {
                 setFamilyName(parts[rightOffset]);
             } else {
                 setGivenName(parts[rightOffset]);
@@ -2131,26 +2125,133 @@ QStringList Addressee::members() const
     return d->mMembers;
 }
 
-void Addressee::insertRelationShip(const Related &relation)
+void Addressee::insertRelationship(const Related &relation)
 {
     d->mEmpty = false;
 
-    if (d->mRelationShips.contains(relation)) {
+    if (d->mRelationships.contains(relation)) {
         return;
     }
 
-    d->mRelationShips.append(relation);
+    d->mRelationships.append(relation);
 }
 
-void Addressee::setRelationShips(const Related::List &c)
+void Addressee::setRelationships(const Related::List &c)
 {
     d->mEmpty = false;
-    d->mRelationShips = c;
+    d->mRelationships = c;
 }
 
-Related::List Addressee::relationShips() const
+Related::List Addressee::relationships() const
 {
-    return d->mRelationShips;
+    return d->mRelationships;
+}
+
+static const auto VENDOR_ID = QStringLiteral("KADDRESSBOOK");
+static const auto X_ANNIVERSARY = QStringLiteral("X-Anniversary");
+static const auto X_ASSISTANTSNAME = QStringLiteral("X-AssistantsName");
+static const auto BLOGFEED = QStringLiteral("BlogFeed");
+static const auto X_MANAGERSNAME = QStringLiteral("X-ManagersName");
+static const auto X_OFFICE = QStringLiteral("X-Office");
+static const auto X_PROFESSION = QStringLiteral("X-Profession");
+static const auto X_SPOUSESNAME = QStringLiteral("X-SpousesName");
+
+QDate Addressee::anniversary() const
+{
+    return QDate::fromString(custom(VENDOR_ID, X_ANNIVERSARY), Qt::ISODate);
+}
+
+void Addressee::setAnniversary(const QDate &anniversary)
+{
+    if (anniversary.isValid()) {
+        insertCustom(VENDOR_ID, X_ANNIVERSARY, anniversary.toString(Qt::ISODate));
+    } else {
+        removeCustom(VENDOR_ID, X_ANNIVERSARY);
+    }
+}
+
+QString Addressee::assistantsName() const
+{
+    return custom(VENDOR_ID, X_ASSISTANTSNAME);
+}
+
+void Addressee::setAssistantsName(const QString &assistantsName)
+{
+    if (!assistantsName.isEmpty()) {
+        insertCustom(VENDOR_ID, X_ASSISTANTSNAME, assistantsName);
+    } else {
+        removeCustom(VENDOR_ID, X_ASSISTANTSNAME);
+    }
+}
+
+QUrl Addressee::blogFeed() const
+{
+    return QUrl(custom(VENDOR_ID, BLOGFEED));
+}
+
+void Addressee::setBlogFeed(const QUrl &blogFeed)
+{
+    if (!blogFeed.isEmpty()) {
+        insertCustom(VENDOR_ID, BLOGFEED, blogFeed.url());
+    } else {
+        removeCustom(VENDOR_ID, BLOGFEED);
+    }
+}
+
+QString Addressee::managersName() const
+{
+    return custom(VENDOR_ID, X_MANAGERSNAME);
+}
+
+void Addressee::setManagersName(const QString &managersName)
+{
+    if (!managersName.isEmpty()) {
+        insertCustom(VENDOR_ID, X_MANAGERSNAME, managersName);
+    } else {
+        removeCustom(VENDOR_ID, X_MANAGERSNAME);
+    }
+}
+
+QString Addressee::office() const
+{
+    return custom(VENDOR_ID, X_OFFICE);
+}
+
+void Addressee::setOffice(const QString &office)
+{
+    if (!office.isEmpty()) {
+        insertCustom(VENDOR_ID, X_OFFICE, office);
+    } else {
+        removeCustom(VENDOR_ID, X_OFFICE);
+    }
+}
+
+QString Addressee::profession() const
+{
+    return custom(VENDOR_ID, X_PROFESSION);
+}
+
+void Addressee::setProfession(const QString &profession)
+{
+    if (!profession.isEmpty()) {
+        insertCustom(VENDOR_ID, X_PROFESSION, profession);
+    } else {
+        removeCustom(VENDOR_ID, X_PROFESSION);
+    }
+}
+
+QString Addressee::spousesName() const
+{
+    return custom(VENDOR_ID, X_SPOUSESNAME);
+}
+
+void Addressee::setSpousesName(const QString &spousesName)
+{
+    if (!spousesName.isEmpty()) {
+        insertCustom(VENDOR_ID, X_SPOUSESNAME, spousesName);
+    } else {
+        removeCustom(VENDOR_ID, X_SPOUSESNAME);
+    }
 }
 
 void Addressee::insertCustom(const QString &app, const QString &name, const QString &value)
@@ -2399,20 +2500,6 @@ bool Addressee::changed() const
     return d->mChanged;
 }
 
-void Addressee::setSortMode(KContacts::SortMode *mode)
-{
-    Private::mSortMode = mode;
-}
-
-bool Addressee::operator<(const Addressee &addr) const
-{
-    if (!Private::mSortMode) {
-        return false;
-    } else {
-        return Private::mSortMode->lesser(*this, addr);
-    }
-}
-
 QString Addressee::mimeType()
 {
     return QStringLiteral("text/directory");
@@ -2458,7 +2545,7 @@ QDataStream &KContacts::operator<<(QDataStream &s, const Addressee &a)
     s << a.d->mLogoExtraList;
     s << a.d->mUrlExtraList;
     s << a.d->mMembers;
-    s << a.d->mRelationShips;
+    s << a.d->mRelationships;
     s << a.d->mSources;
     s << a.d->mImpps;
     s << a.d->mFieldGroupList;
@@ -2513,7 +2600,7 @@ QDataStream &KContacts::operator>>(QDataStream &s, Addressee &a)
     s >> a.d->mLogoExtraList;
     s >> a.d->mUrlExtraList;
     s >> a.d->mMembers;
-    s >> a.d->mRelationShips;
+    s >> a.d->mRelationships;
     s >> a.d->mSources;
     s >> a.d->mImpps;
     s >> a.d->mFieldGroupList;
@@ -2573,3 +2660,41 @@ bool listEquals(const QStringList &list, const QStringList &pattern)
 
     return true;
 }
+
+template <typename T>
+static QVariantList toVariantList(const QVector<T> &v)
+{
+    QVariantList l;
+    l.reserve(v.size());
+    std::transform(v.begin(), v.end(), std::back_inserter(l), [](const T &elem) {
+        return QVariant::fromValue(elem);
+    });
+    return l;
+}
+
+QVariantList Addressee::emailsVariant() const
+{
+    return toVariantList(d->mEmails);
+}
+
+QVariantList Addressee::phoneNumbersVariant() const
+{
+    return toVariantList(d->mPhoneNumbers);
+}
+
+QVariantList Addressee::addressesVariant() const
+{
+    return toVariantList(d->mAddresses);
+}
+
+QVariantList Addressee::urlsVariant() const
+{
+    return toVariantList(d->mUrlExtraList);
+}
+
+QVariantList Addressee::imppsVariant() const
+{
+    return toVariantList(d->mImpps);
+}
+
+#include "moc_addressee.cpp"
